@@ -61,7 +61,7 @@ class Config(object):
         self.parsed_args = parsed_args
 
         if configstream:
-            self.confvalues.update(yaml.load(configstream))
+            self.confvalues.update(yaml.safe_load(configstream))
 
         if parsed_args.debug:
             self.confvalues['log_to_mail'] = False
