@@ -1,7 +1,9 @@
 class AutosplitError(Exception):
     def __init__(self, *args, **kwargs):
-        Exception.__init__(self, *args, **kwargs)
-        if not hasattr(self, 'message'):
+        Exception.__init__(self, *args)
+        if len(self.args) > 0:
+            self.message = self.args[0]
+        else:
             self.message = "Default message"
 
 
